#include "system.h"

EX_INTERRUPT_HANDLER(Sport0RxIsr);
EX_INTERRUPT_HANDLER(Sport0TxIsr);

/********************************************************************************/
/***** Interrupt_Init()														*****/
/***** This function configures SPORT0 TX interrupt as IVG8.				*****/
/********************************************************************************/
void Interrupt_Init(void)
{
	// configure interrupts
	register_handler(ik_ivg8, Sport0RxIsr);		// assign ISR to interrupt vector
	register_handler(ik_ivg9, Sport0TxIsr);		// assign ISR to interrupt vector
	
	*pSIC_IAR1 &= 0xFFFFF00F;
	*pSIC_IAR1 |= 0x00000210;
	*pSIC_IMASK |= 0x00000600;					// enable SPORT0 RX (DMA1) and TX (DMA2) interrupts

}

/********************************************************************************/
/***** SPORT0 TX Interrupt Service Routine									*****/
/***** This ISR uses the pointer pIsrHandling() to call different functions.*****/
/***** As long as the codec initialisation has not finished, pIsrHandling	*****/
/***** points to the function WaitForCodecInit(). This is an empty function;*****/
/***** only the interrupt is needed to skip idle instructions. After the	*****/
/***** codec initialisation, two functions are used alternately. The		*****/
/***** function SkipIsrHandling is used to skip the data handling for every	*****/
/***** second interrupt, since two interrupts are generated per DMA			*****/
/***** transfer. The actual data processing is done in the function			*****/
/***** ProcessData().														*****/
/********************************************************************************/
EX_INTERRUPT_HANDLER(Sport0RxIsr)
{	
	// confirm interrupt handling (NO Error Handling Yet!)
	*pDMA1_IRQ_STATUS |= 0x0001;
	ssync();

	new_block_received = true;					// set semaphore
	Number_of_received_blocks++;				// count
}


EX_INTERRUPT_HANDLER(Sport0TxIsr)
{	
	// confirm interrupt handling (NO Error Handling Yet!)
	*pDMA2_IRQ_STATUS |= 0x0001;
	ssync();

	block_transmitted = true;					// set semaphore
	Number_of_transmitted_blocks++;				// count
}

